Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8)

Unified Diff: blimp/client/app/android/ime_helper_dialog.h

Issue 2261853002: Changed Blimp IME to use PopUp (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@ime_popup
Patch Set: Used AlertDialog from support.v7 Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « blimp/client/app/android/blimp_app_jni_registrar.cc ('k') | blimp/client/app/android/ime_helper_dialog.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: blimp/client/app/android/ime_helper_dialog.h
diff --git a/blimp/client/app/android/web_input_box.h b/blimp/client/app/android/ime_helper_dialog.h
similarity index 67%
rename from blimp/client/app/android/web_input_box.h
rename to blimp/client/app/android/ime_helper_dialog.h
index 289af53a63b7151a8e6d2c6b6f32de5aa9fc10f6..ce419b928d782b954c350008abc7e5c0e201a16f 100644
--- a/blimp/client/app/android/web_input_box.h
+++ b/blimp/client/app/android/ime_helper_dialog.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef BLIMP_CLIENT_APP_ANDROID_WEB_INPUT_BOX_H_
-#define BLIMP_CLIENT_APP_ANDROID_WEB_INPUT_BOX_H_
+#ifndef BLIMP_CLIENT_APP_ANDROID_IME_HELPER_DIALOG_H_
+#define BLIMP_CLIENT_APP_ANDROID_IME_HELPER_DIALOG_H_
#include <string>
@@ -15,15 +15,15 @@
namespace blimp {
namespace client {
-// The native component of org.chromium.blimp.input.WebInputBox.
-class WebInputBox : public ImeFeature::Delegate {
+// The native component of org.chromium.blimp.input.ImeHelperDialog.
+class ImeHelperDialog : public ImeFeature::Delegate {
public:
static bool RegisterJni(JNIEnv* env);
- // |ime_feature| is expected to outlive the WebInputBox.
- WebInputBox(JNIEnv* env,
- const base::android::JavaParamRef<jobject>& jobj,
- ImeFeature* ime_feature);
+ // |ime_feature| is expected to outlive the ImeHelperDialog.
+ ImeHelperDialog(JNIEnv* env,
+ const base::android::JavaParamRef<jobject>& jobj,
+ ImeFeature* ime_feature);
// Brings up IME for user to enter text.
void OnShowImeRequested(ui::TextInputType input_type,
@@ -35,13 +35,13 @@ class WebInputBox : public ImeFeature::Delegate {
// Methods called from Java via JNI.
void Destroy(JNIEnv* env, const base::android::JavaParamRef<jobject>& jobj);
- // Sends the text entered from IME to the blimp engine
+ // Sends the text entered from IME to the blimp engine.
void OnImeTextEntered(JNIEnv* env,
const base::android::JavaParamRef<jobject>& jobj,
const base::android::JavaParamRef<jstring>& text);
private:
- ~WebInputBox() override;
+ ~ImeHelperDialog() override;
// Reference to the Java object which owns this class.
base::android::ScopedJavaGlobalRef<jobject> java_obj_;
@@ -50,10 +50,10 @@ class WebInputBox : public ImeFeature::Delegate {
// outgoing and incoming BlimpMessage::IME messages from the engine.
ImeFeature* ime_feature_;
- DISALLOW_COPY_AND_ASSIGN(WebInputBox);
+ DISALLOW_COPY_AND_ASSIGN(ImeHelperDialog);
};
} // namespace client
} // namespace blimp
-#endif // BLIMP_CLIENT_APP_ANDROID_WEB_INPUT_BOX_H_
+#endif // BLIMP_CLIENT_APP_ANDROID_IME_HELPER_DIALOG_H_
« no previous file with comments | « blimp/client/app/android/blimp_app_jni_registrar.cc ('k') | blimp/client/app/android/ime_helper_dialog.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698